%define module	nose
%{!?python_version: %global python_version %(%{__python} -c "import sys ; print sys.version[:3]")}
%{!?python3_version: %global python3_version %(%{__python3} -c "import sys; sys.stdout.write(sys.version[:3])")}

Summary:	Unittest-based testing framework for Python
Name:		python-%{module}
Version:	1.3.7
Release:	%mkrel 1
Source0:	https://pypi.python.org/packages/source/n/nose/%{module}-%{version}.tar.xz
License:	LGPLv2+
Group:		Development/Python
Url:		http://readthedocs.org/docs/nose/
BuildArch:	noarch
BuildRequires:	python-sphinx >= 0.6.0
BuildRequires:	pkgconfig(python)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-coverage >= 3.4-1
BuildRequires:	python-coverage >= 3.4-1
BuildRequires:	dos2unix
BuildRequires:	python-setuptools
BuildRequires:	python3-setuptools
Requires:	python-setuptools

%description
nose extends the test loading and running features of unittest, making it easier
to write, find and run tests.

By default, nose will run tests in files or directories under the current
working directory whose names include "test" or "Test" at a word boundary (like
"test_this" or "functional_test" or "TestClass" but not "libtest"). Test output
is similar to that of unittest, but also includes captured stdout output from
failing tests, for easy print-style debugging.

These features, and many more, are customizable through the use of plugins.
Plugins included with nose provide support for doctest, code coverage and
profiling, flexible attribute-based test selection, output capture and more.

%package docs
Summary:	Nose Documentation
Group:		Documentation
#BuildRequires:	python-sphinx
Requires:	python-nose

%description docs
Documentation for Nose

%package -n python3-%{module}
Summary:	Discovery-based unittest extension for Python3
Group:		Development/Python
Requires:	python3-setuptools

%description -n python3-%{module}
nose extends the test loading and running features of unittest, making it easier
to write, find and run tests.

By default, nose will run tests in files or directories under the current
working directory whose names include "test" or "Test" at a word boundary (like
"test_this" or "functional_test" or "TestClass" but not "libtest"). Test output
is similar to that of unittest, but also includes captured stdout output from
failing tests, for easy print-style debugging.

This package installs the nose module and nosetests3 program that can discover
python3 unittests.

%prep
%setup -q -n %{module}-%{version}
dos2unix examples/attrib_plugin.py

rm -rf %{py3dir}
cp -a . %{py3dir}

%build
%{__python} setup.py build

pushd %{py3dir}
%{__python3} setup.py build
popd

%install
# Must do the python3 install first because the scripts in /usr/bin are
# overwritten with every setup.py install (and we want the python2 version
# to be the default for now).
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
rm %{buildroot}%{_bindir}/nosetests
mkdir -m 0755 -p %{buildroot}%{_mandir}/man1/
mv %{buildroot}%{_prefix}/man/man1/nosetests.1 %{buildroot}%{_mandir}/man1/nosetests-%{python3_version}.1
%__lzma -z %{buildroot}%{_mandir}/man1/nosetests-%{python3_version}.1 
popd

%{__python} setup.py install --skip-build --root=%{buildroot} --install-data=%{_datadir}
%__lzma -z %{buildroot}%{_mandir}/man1/nosetests.1 

pushd doc
make html
rm -rf .build/html/.buildinfo .build/html/_sources
mv .build/html ..
rm -rf .build
popd
cp -a doc reST
rm -rf reST/.static reST/.templates

%check
# Various selftests fail on our build system; skip them for now using "-e"
%{__python} selftest.py -e test_multiprocessing

pushd %{py3dir}
export PYTHONPATH=`pwd`/build/lib
%{__python3} setup.py build_tests
%{__python3} selftest.py -e test_multiprocessing
popd

%files 
%doc AUTHORS CHANGELOG lgpl.txt NEWS README.txt
%{_bindir}/nosetests
%{_bindir}/nosetests-%{python_version}
%{_mandir}/man1/nosetests.*
%{python_sitelib}/nose*

%files -n python3-%{module}
%doc AUTHORS CHANGELOG lgpl.txt NEWS README.txt
%{_bindir}/nosetests-%{python3_version}
%{_mandir}/man1/nosetests-%{python3_version}.*
%{python3_sitelib}/nose*

%files docs
%doc reST examples
%doc html



%changelog
* Sat Jun 27 2015 gseaman <galen.seaman at comcast.net> 1.3.7-1gseaman2015
- rebase on Mageia spec for python3
